<?php

/***************************************************************************
 *                            lang_admin.php [Thai]
 *                              -------------------
 *     begin                : Sat Dec 16 2000
 *     copyright            : (C) 2001 The phpBB Group
 *     email                : support@phpbb.com
 *
 *     Translation: SuperToy_nc < SuperToy_nc@yahoo.com > 
 *
 *     $Id: lang_admin.php,v 1.35.2.9 2003/06/10 00:31:19 psotfx Exp $
 *
 ****************************************************************************/

/***************************************************************************
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or
 *   (at your option) any later version.
 *
 ***************************************************************************/

/* CONTRIBUTORS
	2002-12-15	Philip M. White (pwhite@mailhaven.com)
		Fixed many minor grammatical mistakes
*/

//
// Format is same as lang_main
//

//
// Modules, this replaces the keys used
// in the modules[][] arrays in each module file
//
$lang['General'] = 'General Admin';
$lang['Users'] = 'User Admin';
$lang['Groups'] = 'Group Admin';
$lang['Forums'] = 'Forum Admin';
$lang['Styles'] = 'Styles Admin';

$lang['Configuration'] = 'õ駤ҷ';
$lang['Permissions'] = '͹حҵ';
$lang['Manage'] = 'õ駤ҵ͡';
$lang['Disallow'] = 'ͷ͹حҵ';
$lang['Prune'] = 'źǢͷաõͺ';
$lang['Mass_Email'] = ' Email 繡';
$lang['Ranks'] = 'дѺ';
$lang['Smilies'] = 'ٻ';
$lang['Ban_Management'] = '';
$lang['Word_Censor'] = 'ǧ';
$lang['Export'] = '͡';
$lang['Create_new'] = 'ҧ';
$lang['Add_new'] = '';
$lang['Backup_DB'] = 'ͧҹ';
$lang['Restore_DB'] = '׹ҹ';


//
// Index
//
$lang['Admin'] = 'Administration';
$lang['Not_admin'] = 'س administer ͧ촹';
$lang['Welcome_phpBB'] = 'Թյ͹Ѻ phpBB';
$lang['Admin_intro'] = 'ͺس phpBB. ˹ҹʴʶԵԵҧͧ. سöѺҷ˹ҹ¤ԡ <u>Admin Index</u> 觫. ҵͧáѺ价 ԡ phpBB 觫. ǹԧ觫 йӤسäǺǹҧ ˹Ҩդйӡ͡.';
$lang['Main_index'] = 'Forum Index';
$lang['Forum_stats'] = 'ʶԵԢͧ Forum';
$lang['Admin_Index'] = 'Admin Index';
$lang['Preview_forum'] = 'Դ Forum 㹽觢';

$lang['Click_return_admin_index'] = 'ԡ %s%s ͡Ѻ˹ Admin Index';

$lang['Statistic'] = 'ʶԵ';
$lang['Value'] = '';
$lang['Number_posts'] = 'ӹǹͤ';
$lang['Posts_per_day'] = 'ͤѹ';
$lang['Number_topics'] = 'ӹǹǢ';
$lang['Topics_per_day'] = 'Ǣ͵ѹ';
$lang['Number_users'] = 'ӹǹ';
$lang['Users_per_day'] = 'ѹ';
$lang['Board_started'] = '';
$lang['Avatar_dir_size'] = 'Ҵͧ directory ٻШӵ';
$lang['Database_size'] = 'Ҵͧҹ';
$lang['Gzip_compression'] ='úպѴẺ Gzip';
$lang['Not_available'] = '(Һ)';

$lang['ON'] = ''; // This is for GZip compression
$lang['OFF'] = ''; 


//
// DB Utils
//
$lang['Database_Utilities'] = 'ͧѺҹ';

$lang['Restore'] = '׹ҹ';
$lang['Backup'] = 'ͧҹ';
$lang['Restore_explain'] = '׹ҹ phpBB ҡѹ֡.  server ʹѺʹعúպѴẺ gzip ж١ѵѵ. <b>͹</b> Ҩж١¹Ѻ. á׹ѡ س¹˹ҨҨзӧҹ';
$lang['Backup_explain'] = 'سöͧҹŢͧ phpBB . Ҥسյҧǹ㹰ҹ phpBB سͧͧ سһ͹Ф蹴١ ŧ \'ҧ\' ҹҧ.  server ͧѺúպѴẺ gzip зӹǹŷسͧ download ŧ<br>ҧǹǷͧ <b>attach_quota,attachments,attachments_config,attachments_desc,extension_groups,extensions,forbidden_extensions,quota_limits</b>';

$lang['Backup_options'] = 'ͧ͡';
$lang['Start_backup'] = 'ӡͧ';
$lang['Full_backup'] = 'ͧ';
$lang['Structure_backup'] = 'ͧ੾çҧ';
$lang['Data_backup'] = 'ͧ੾Т';
$lang['Additional_tables'] = 'ҧ';
$lang['phpBB_only'] = '੾еҧǡѺ phpBB ҹ';
$lang['Gzip_compress'] = 'úպѴẺ Gzip';
$lang['Select_file'] = '͡';
$lang['Start_Restore'] = 'ӡá׹';

$lang['Restore_success'] = '׹ҹº<br /><br />촨СѺʶҹش·ӡͧ';
$lang['Backup_download'] = ' download ǹ سѡ';
$lang['Backups_not_supported'] = '. ҹŹͧѺͧ';

$lang['Restore_Error_uploading'] = ' upload  ԴüԴҴ';
$lang['Restore_Error_filename'] = 'ջѭ, سͧ¹';
$lang['Restore_Error_decompress'] = 'öպѴẺ gzip, س upload 쪹Դѡø';
$lang['Restore_Error_no_file'] = '١ upload';


//
// Auth pages
//
$lang['Select_a_User'] = '͡';
$lang['Select_a_Group'] = '͡';
$lang['Select_a_Forum'] = '͡ forum';
$lang['Auth_Control_User'] = 'Ǻ͹حҵ';
$lang['Auth_Control_Group'] = 'Ǻ͹حҵ';
$lang['Auth_Control_Forum'] = 'Ǻ͹حҵ forum';
$lang['Look_up_User'] = 'ŧ';
$lang['Look_up_Group'] = 'ŧ';
$lang['Look_up_Forum'] = 'ŧ';

$lang['Group_auth_explain'] = 'سö¹ŧ͹حҵ ʶҹ moderator ͧС.  ¹ŧ͹حҵͧ ͹حҵѺºؤҨѧ Ҩѧö forum . 㹡óչ سѺ͹.';
$lang['User_auth_explain'] = 'سö¹ŧ͹حҵ ʶҹ moderator ͧФ.  ¹ŧ͹حҵͧ ͹حҵѺҨѧ Ҩѧö forum . 㹡óչ سѺ͹.';
$lang['Forum_auth_explain'] = 'سö¹ŧдѺ͹حҵͧ forum. سö͡Ẻҧ Ẻ٧, Ըժ٧äǺ forum С÷ӧҹա.';

$lang['Simple_mode'] = 'Ẻ';
$lang['Advanced_mode'] = 'Ẻ٧';
$lang['Moderator_status'] = 'ʶҹ Moderator';

$lang['Allowed_Access'] = '͹حҵҶ֧';
$lang['Disallowed_Access'] = '͹حҵҶ֧';
$lang['Is_Moderator'] = ' Moderator';
$lang['Not_Moderator'] = ' Moderator';

$lang['Conflict_warning'] = '͹حҵԴâѴ駡ѹ';
$lang['Conflict_access_userauth'] = 'ѧԷѧ forum ҹҧҪԡ. سҨͧ¹͹حҵ ź͡ҡ. ͹حҵͧ (Тͧ forum Ǣͧ) ͸Ժҧҧ';
$lang['Conflict_mod_userauth'] = 'ѧԷͧ moderator ѧ forum. سҨͧ¹͹حҵ ź͡ҡ ͻͧѹԷ moderator. ͹حҵͧ (Тͧ forum Ǣͧ) ͸Ժҧҧ';

$lang['Conflict_access_groupauth'] = '()ѧԷѧ forum ҹҧҪԡ. سҨͧ¹͹حҵѺ. ͹حҵͧ (Тͧ forum Ǣͧ) ʴҹҧ';
$lang['Conflict_mod_groupauth'] = '()ѧԷͧ moderator ѧ forum.  سҨͧ¹͹حҵѺ ͻͧѹԷ moderator. ͹حҵͧ (Тͧ forum Ǣͧ) ʴҹҧ';

$lang['Public'] = 'Ҹó';
$lang['Private'] = 'ǹ';
$lang['Registered'] = 'ŧ¹';
$lang['Administrators'] = 'Administrators';
$lang['Hidden'] = '١͹';

// These are displayed in the drop down boxes for advanced
// mode forum auth, try and keep them short!
$lang['Forum_ALL'] = '';
$lang['Forum_REG'] = 'ŧ¹';
$lang['Forum_PRIVATE'] = 'ǹ';
$lang['Forum_MOD'] = 'MOD';
$lang['Forum_ADMIN'] = 'ADMIN';

$lang['View'] = 'Ǣ';
$lang['Read'] = 'ҹͤ';
$lang['Post'] = 'Ǣ';
$lang['Reply'] = 'ͺ';
$lang['Edit'] = '';
$lang['Delete'] = 'ź';
$lang['Sticky'] = 'Sticky';
$lang['Announce'] = 'ҧС'; 
$lang['Vote'] = 'ŧṹ';
$lang['Pollcreate'] = 'ҧẺͺ';

$lang['Permissions'] = '͹حҵ';
$lang['Simple_Permission'] = '͹حҵ鹰ҹ';

$lang['User_Level'] = 'дѺ'; 
$lang['Auth_User'] = '';
$lang['Auth_Admin'] = 'Administrator';
$lang['Group_memberships'] = 'ʶҹСҪԡ';
$lang['Usergroup_members'] = 'ªͼ㹡ѧ';

$lang['Forum_auth_updated'] = 'Ѻا͹حҵѺ forum ';
$lang['User_auth_updated'] = 'Ѻا͹حҵѺ';
$lang['Group_auth_updated'] = 'Ѻا͹حҵѺ';

$lang['Auth_updated'] = 'Ѻا͹حҵ';
$lang['Click_return_userauth'] = 'ԡ %s%s ͡Ѻ˹ \'͹حҵѺ\'';
$lang['Click_return_groupauth'] = 'ԡ %s%s ͡Ѻ˹ \'͹حҵѺ\'';
$lang['Click_return_forumauth'] = 'ԡ %s%s ͡Ѻ˹ \'͹حҵѺ forum\'';


//
// Banning
//
$lang['Ban_control'] = 'Ǻ';
$lang['Ban_explain'] = 'سöǺ. سöºؤ / ͧ IP address  hostnames. ԸչлͧѹҶ֧˹áͧ. ҨлͧѹҡѤҪԡ͵ҧ سöк e-mail ͧ.  e-mail §ҧǨöͧѹ鹨ҡк 觢ͤ㹺 س˹ͧԸáѺ䢻ѭҹ.';
$lang['Ban_explain_warn'] = 'ôѧ кءͧ IP address ռšѺء IP ҧ IP ش. Ţ IP кѹ֡ŧҹŨ wildcards ѵѵŴҴͧ IP. Ҥسͧкتǧͧ IP ԧ سкتǧ᤺شҷз.';

$lang['Select_username'] = '͡ username';
$lang['Select_ip'] = '͡ IP';
$lang['Select_email'] = '͡ Email';

$lang['Ban_username'] = ' 1 ҡ';
$lang['Ban_username_explain'] = 'سö¤㹤 Фѹ';

$lang['Ban_IP'] = ' IP 1 Ţҡ ͪ host';
$lang['IP_hostname'] = 'Ţ IP ͪ host';
$lang['Ban_IP_explain'] = 'кŢ IP  hostname Ъʹ١. Ҩкتǧͧ IP ¡Ţش¢մ (-), Ҩк wildcard  *';

$lang['Ban_email'] = ' 1 Email ҡ';
$lang['Ban_email_explain'] = 'Ҩкҡ 1 email 蹴١. Ҩк wildcard  *  *@hotmail.com';

$lang['Unban_username'] = '¡ԡ 1 ҡ';
$lang['Unban_username_explain'] = 'سö¡ԡª㹤 Фѹ';

$lang['Unban_IP'] = '¡ԡ IP 1 Ţҡ';
$lang['Unban_IP_explain'] = 'سö¡ԡ IP 㹤 Фѹ';

$lang['Unban_email'] = '¡ԡ 1 Email ҡ';
$lang['Unban_email_explain'] = 'سö¡ԡ email 㹤 Фѹ';

$lang['No_banned_users'] = 'ա';
$lang['No_banned_ip'] = 'աŢ IP';
$lang['No_banned_email'] = 'ա Email';

$lang['Ban_update_sucessful'] = 'Ѻاª͡';
$lang['Click_return_banadmin'] = 'ԡ %s%s ͡Ѻ˹ \'Ǻ\'';


//
// Configuration
//
$lang['General_Config'] = 'õ駤ҷ';
$lang['Config_explain'] = 'Ẻҹҧ سѺ觤ҵҧͧ. ҵͧõ駤Ѻ forum ԧ觫᷹.';

$lang['Click_return_config'] = 'ԡ %s%s ͡Ѻ˹ \'õ駤ҷ\'';

$lang['General_settings'] = '駤ҷ仢ͧ';
$lang['Server_name'] = 'Domain Name';
$lang['Server_name_explain'] = '촹١¡ҡ Domain Name';
$lang['Script_path'] = '˹';
$lang['Script_path_explain'] = '˹觢ͧ phpBB2 ѹѺ Domain Name';
$lang['Server_port'] = 'Server Port';
$lang['Server_port_explain'] = 'Ţ port ͧ server, áԤ 80';
$lang['Site_name'] = '';
$lang['Site_desc'] = '´ͧ';
$lang['Board_disable'] = '¡ԡ';
$lang['Board_disable_explain'] = 'ҹ. ͡ҡкͤس¡ԡ Фسöкա!';
$lang['Acct_activation'] = 'ͧ׹ѹѭմ';
$lang['Acc_None'] = 'ͧ'; // These three entries are the type of activation
$lang['Acc_User'] = '׹ѹҡԧ email';
$lang['Acc_Admin'] = 'Admin 繼׹ѹ';

$lang['Abilities_settings'] = 'õ駤Ҿ鹰ҹͧ forum';
$lang['Max_poll_options'] = 'ӹǹ͡ѺẺͺ Թ';
$lang['Flood_Interval'] = 'һͧѹ觢ͤѹ';
$lang['Flood_Interval_explain'] = 'ӹǹԹҷշͧ ҧ觢ͤԴѹ'; 
$lang['Board_email_form'] = ' Email ҧҹ';
$lang['Board_email_form_explain'] = '͹حҵ Email ֧ѹ ҹͧ촹';
$lang['Topics_per_page'] = 'ӹǹǢ͵˹';
$lang['Posts_per_page'] = 'ӹǹͤ˹';
$lang['Hot_threshold'] = 'ӹǹõͺ Ѻ';
$lang['Default_style'] = 'ٻẺҵðҹ';
$lang['Override_style'] = 'ѧѺѺء';
$lang['Override_style_explain'] = '᷹ٻẺͧ͡ ٻẺҵðҹ';
$lang['Default_language'] = 'ҵðҹ';
$lang['Date_format'] = 'ٻẺѹҵðҹ';
$lang['System_timezone'] = 'ûѺ timezone';
$lang['Enable_gzip'] = 'úպѴẺ GZip';
$lang['Enable_prune'] = 'ź forum ռͺҹԹ';
$lang['Allow_HTML'] = ' HTML';
$lang['Allow_BBCode'] = ' BBCode';
$lang['Allowed_tags'] = ' HTML';
$lang['Allowed_tags_explain'] = 'Ф觴١';
$lang['Allow_smilies'] = 'ٻ';
$lang['Smilies_path'] = '˹觷ٻ';
$lang['Smilies_path_explain'] = ' rood directory ͧ phpBB  images/smiles';
$lang['Allow_sig'] = '';
$lang['Max_sig_length'] = ' Թ [ ѡ ]';
$lang['Max_sig_length_explain'] = 'ӹǹѡ٧شͧ';
$lang['Allow_name_change'] = '¹ username';

$lang['Avatar_settings'] = 'õ駤ٻШӵ';
$lang['Allow_local'] = 'öٻҵðҹ';
$lang['Allow_remote'] = 'öٻҡ URL ';
$lang['Allow_remote_explain'] = 'ٻҾ躹 ٻШӵ';
$lang['Allow_upload'] = 'ö upload ٻШӵ';
$lang['Max_filesize'] = 'ҴٻШӵ Թ';
$lang['Max_filesize_explain'] = 'Ѻ upload ٻШӵ';
$lang['Max_avatar_size'] = 'ҴٻШӵ Թ';
$lang['Max_avatar_size_explain'] = '(٧ x ҧ ˹ pixels)';
$lang['Avatar_storage_path'] = '˹ٻШӵ';
$lang['Avatar_storage_path_explain'] = ' root directory ͧ phpBB  images/avatars';
$lang['Avatar_gallery_path'] = '˹ٻШӵǷ';
$lang['Avatar_gallery_path_explain'] = ' directory ͧҧ  images/avatars/gallery';

$lang['COPPA_settings'] = 'COPPA Settings';
$lang['COPPA_fax'] = 'COPPA Fax Number';
$lang['COPPA_mail'] = 'COPPA Mailing Address';
$lang['COPPA_mail_explain'] = 'This is the mailing address where parents will send COPPA registration forms';

$lang['Email_settings'] = 'õ駤 Email';
$lang['Admin_email'] = 'Email ͧ Admin';
$lang['Email_sig'] = '繢ͧ Email';
$lang['Email_sig_explain'] = 'ͤṺ仡Ѻ Email ءѺ 觨ҡ';
$lang['Use_SMTP'] = ' SMTP Server 㹡 Email';
$lang['Use_SMTP_explain'] = 'ͺ \'\' ͤسͧͨ繵ͧ Email ҹ SMTP server ᷹ѧѹ Email ͧͧ';
$lang['SMTP_server'] = 'ͧ SMTP Server';
$lang['SMTP_username'] = 'SMTP Username';
$lang['SMTP_username_explain'] = '͹ username ͨ繵ͧҹ';
$lang['SMTP_password'] = 'SMTP Password';
$lang['SMTP_password_explain'] = '͹ password ͨ繵ͧҹ';

$lang['Disable_privmsg'] = 'ͤǹ';
$lang['Inbox_limits'] = 'ͤ Inbox Թ';
$lang['Sentbox_limits'] = 'ͤ Sentbox Թ';
$lang['Savebox_limits'] = 'ͤ Savebox Թ';

$lang['Cookie_settings'] = 'õ駤 Cookie'; 
$lang['Cookie_settings_explain'] = '´Ѻ cookies ١价 browsers ͧس. ·令ҵðҹ§ Ҥسͧ¹ŧ سҷӴ¤Ѵѧ õ駤ҷԴҴ зöк';
$lang['Cookie_domain'] = 'Cookie Domain';
$lang['Cookie_name'] = ' Cookie';
$lang['Cookie_path'] = '˹觢ͧ Cookie';
$lang['Cookie_secure'] = 'ʹ¢ͧ Cookie';
$lang['Cookie_secure_explain'] = ' server ͧس SSL Դҹ';
$lang['Session_length'] = ' [ Թҷ ]';

// Visual Confirmation
$lang['Visual_confirm'] = 'Դ׹ѹٻҾ';
$lang['Visual_confirm_explain'] = 'еͧ͡ʷٻҾͷӡѤҪԡ';

//
// Forum Management
//
$lang['Forum_admin'] = 'èѴ forum';
$lang['Forum_admin_explain'] = 'ǹسö, ź, , §ӴѺ, Ѵ§ forum ';
$lang['Edit_forum'] = ' forum';
$lang['Create_forum'] = 'ҧ forum ';
$lang['Create_category'] = 'ҧ';
$lang['Remove'] = 'ź';
$lang['Action'] = 'з';
$lang['Update_order'] = 'ѺاӴѺ';
$lang['Config_updated'] = 'Ѻاõ駤Ңͧ forum ';
$lang['Edit'] = '';
$lang['Delete'] = 'ź';
$lang['Move_up'] = '͹';
$lang['Move_down'] = '͹ŧ';
$lang['Resync'] = 'Ѵº';
$lang['No_mode'] = 'աõ mode';
$lang['Forum_edit_delete_explain'] = 'Ẻҹҧ س䢢´ͧ forum ͡';

$lang['Move_contents'] = '¢ͤ';
$lang['Forum_delete'] = 'ź forum';
$lang['Forum_delete_explain'] = 'Ẻҹҧ سź forum (͡) س͡ йǢ ( forum) .';

$lang['Status_locked'] = '١͡';
$lang['Status_unlocked'] = '١Ŵ͡';
$lang['Forum_settings'] = 'õ駤Ҿ鹰ҹͧ forum';
$lang['Forum_name'] = ' forum';
$lang['Forum_desc'] = '´';
$lang['Forum_status'] = 'ʶҹТͧ forum';
$lang['Forum_pruning'] = 'źѵѵ';

$lang['prune_freq'] = 'ǨͺǢͷ forum ء';
$lang['prune_days'] = 'źǢ աõͺԹ';
$lang['Set_prune_data'] = 'سԴкźǢѵѵ Ѻ forum  ͨӹǹѹ͵Ǩͺ. سҤԡ back ͡Ѻ';

$lang['Move_and_Delete'] = 'ź';

$lang['Delete_all_posts'] = 'źͤ';
$lang['Nowhere_to_move'] = 'кػ·ҧ';

$lang['Edit_Category'] = '䢪͡';
$lang['Edit_Category_explain'] = 'Ẻ䢪͡.';

$lang['Forums_updated'] = 'ѺاŢͧ forum С';

$lang['Must_delete_forums'] = 'سеͧźء forum ͹ź';

$lang['Click_return_forumadmin'] = 'ԡ %s%s ͡Ѻ˹ \'èѴ Forum\'';


//
// Smiley Management
//
$lang['smiley_title'] = 'ͧٻ';
$lang['smile_desc'] = '˹ҹ سö, ź  ٻʴ ٻ ö㹢ͤТͤǹ.';

$lang['smiley_config'] = 'õ駤ٻ';
$lang['smiley_code'] = 'Code';
$lang['smiley_url'] = 'ٻҾ';
$lang['smiley_emot'] = '͸Ժ';
$lang['smile_add'] = 'ٻ';
$lang['Smile'] = 'ٻ';
$lang['Emotion'] = '͸Ժ';

$lang['Select_pak'] = '͡ Pack (.pak)';
$lang['replace_existing'] = '᷹ٻ';
$lang['keep_existing'] = 'ٻ';
$lang['smiley_import_inst'] = 'س unzip 礢ͧٻ 觷ء价 directory ٻ ͹ӡõԴ. ҡ͡ŷ١ͧẺ ͹ٻ.';
$lang['smiley_import'] = '礢ͧٻ';
$lang['choose_smile_pak'] = '͡ (.pak) ͧٻ';
$lang['import'] = 'ٻ';
$lang['smile_conflicts'] = 'èзҧ;ٻ';
$lang['del_existing_smileys'] = 'źٻҡ͹';
$lang['import_smile_pack'] = '礢ͧٻ';
$lang['export_smile_pack'] = 'ҧ礢ͧٻ';
$lang['export_smiles'] = 'ҧ礢ͧٻҡٻԴ ԡ %s%s  download  smiles.pak Ǩ͹ҹءŢͧ .pak ҡ download ٻҾ  smiles.pak ٻҾ ҧ zip';

$lang['smiley_add_success'] = 'ٻº';
$lang['smiley_edit_success'] = 'Ѻاٻº';
$lang['smiley_import_success'] = '礢ͧٻº';
$lang['smiley_del_success'] = 'źٻº';
$lang['Click_return_smileadmin'] = 'ԡ %s%s ͡Ѻ˹ \'ٻ\'';


//
// User Management
//
$lang['User_admin'] = 'õ駤Һѭռ';
$lang['User_admin_explain'] = 'سö¹ŧ´ͧ е͡ҧ. Ҩ䢡͹حҵ к͹حҵѺС';

$lang['Look_up_user'] = 'ŧ';

$lang['Admin_user_fail'] = 'öѺاǹǢͧ';
$lang['Admin_user_updated'] = 'ѺاǹǢͧ';
$lang['Click_return_useradmin'] = 'ԡ %s%s ͡Ѻ˹ \'õ駤Һѭռ\'';

$lang['User_delete'] = 'ź';
$lang['User_delete_explain'] = 'ԡź, ö¡ԡ';
$lang['User_deleted'] = 'ź';

$lang['User_status'] = 'Դҹ';
$lang['User_allowpm'] = 'ö觢ͤǹ';
$lang['User_allowavatar'] = 'öٻШӵ';

$lang['Admin_avatar_explain'] = 'سöźٻШӵǢͧ';

$lang['User_special'] = 'ǹ Ѻ admin ҹ';
$lang['User_special_explain'] = 'ǹö¼. سöʶҹе͡ ö';


//
// Group Management
//
$lang['Group_administration'] = 'õ駤ҡ';
$lang['Group_admin_explain'] = 'سöѴá سö ź, ҧ 䢡 سҨ͡ moderator, ѺʶҹԴ/Դ е駪͡Ф͸Ժ';
$lang['Error_updating_groups'] = 'ԴͼԴҴҧѺا';
$lang['Updated_group'] = 'Ѻاº';
$lang['Added_new_group'] = 'ҧº';
$lang['Deleted_group'] = 'źº';
$lang['New_group'] = 'ҧ';
$lang['Edit_group'] = '䢡';
$lang['group_name'] = '͡';
$lang['group_description'] = '͸Ժ¡';
$lang['group_moderator'] = 'moderator ͧ';
$lang['group_status'] = 'ʶҹС';
$lang['group_open'] = 'Դ';
$lang['group_closed'] = '١Դ';
$lang['group_hidden'] = '١͹';
$lang['group_delete'] = 'ź';
$lang['group_delete_check'] = 'ź';
$lang['submit_group_changes'] = 'ѹ֡¹ŧ';
$lang['reset_group_changes'] = '¡ԡ¹ŧ';
$lang['No_group_name'] = 'سͧкت͡';
$lang['No_group_moderator'] = 'سͧкؼ moderator ͧ';
$lang['No_group_mode'] = 'سͧкʶҹТͧ Դ Ͷ١Դ';
$lang['No_group_action'] = 'кءáз';
$lang['delete_group_moderator'] = 'ź moderator Ңͧ?';
$lang['delete_moderator_explain'] = 'Ҥسѧ¹ŧ moderator ͧ ͧ͡ź moderator ͡ҡ Ͷ͡ СҪԡҢͧ';
$lang['Click_return_groupsadmin'] = 'ԡ %s%s ͡Ѻ \'õ駤ҡ\'';
$lang['Select_group'] = '͡';
$lang['Look_up_group'] = 'ŧ';


//
// Prune Administration
//
$lang['Forum_Prune'] = 'źǢͷաõͺ';
$lang['Forum_Prune_explain'] = 'źǢͷռͺӹǹѹ˹. Ҥسкبӹǹѹ, ءǢͨж١ź. źǢͷẺͺѧӧҹ ШźͤС. سеͧźǢҹµͧ.';
$lang['Do_Prune'] = 'ŧ';
$lang['All_Forums'] = 'ء forum';
$lang['Prune_topics_not_posted'] = 'źǢͷաõͺҹԹ';
$lang['Topics_pruned'] = 'ӹǹǢͷ١ź';
$lang['Posts_pruned'] = 'ӹǹͤ١ź';
$lang['Prune_success'] = 'ӡź forum º';


//
// Word censor
//
$lang['Words_title'] = 'ǧ';
$lang['Words_explain'] = 'سö, , ź  forums. мöŧ¹ͷդҹ. سö Wildcards (*) 㹤  *test* ǧ detestable, test* ǧ testing, *test ǧ detest.';
$lang['Word'] = 'ǧ';
$lang['Edit_word_censor'] = '䢤ǧ';
$lang['Replacement'] = 'ӷж١᷹ŧ';
$lang['Add_new_word'] = '';
$lang['Update_word'] = 'Ѻاǧ';

$lang['Must_enter_word'] = 'سͧкؤǧ Фӷж١᷹ŧ᷹';
$lang['No_word_selected'] = '͡ӷͧ';

$lang['Word_updated'] = 'Ѻاǧ١͡º';
$lang['Word_added'] = 'ǧº';
$lang['Word_removed'] = 'źǧ١͡º';

$lang['Click_return_wordadmin'] = 'ԡ %s%s ͡Ѻ˹ \'ǧ\'';


//
// Mass Email
//
$lang['Mass_email_explain'] = 'سö e-mail ء ͼء㹡к. Email 鹩Ѻж١价 email address ͧ admin к  BCC (blind carbon copy) Ѻء. Ҥس email ˭ سʹѧ ҡشҧ÷ӧҹ. ˵ءóáԷͧҹҹ سѺкӧҹº';
$lang['Compose'] = '¹ email'; 

$lang['Recipients'] = 'Ѻ'; 
$lang['All_users'] = 'ء';

$lang['Email_successfull'] = 'ͤ١';
$lang['Click_return_massemail'] = 'ԡ %s%s ͡ѺẺ \' Email 繡\'';


//
// Ranks admin
//
$lang['Ranks_title'] = 'дѺ';
$lang['Ranks_explain'] = 'سö, ,  źдѺ. ФسöҧдѺѺ ҹҧèѴü';

$lang['Add_new_rank'] = 'дѺ';

$lang['Rank_title'] = 'дѺ';
$lang['Rank_special'] = 'дѺ鹾';
$lang['Rank_minimum'] = 'ӹǹ post ش';
$lang['Rank_maximum'] = 'ӹǹ post ҡش';
$lang['Rank_image'] = 'ٻҾͧдѺ鹹 (㹵˹ root ͧ phpBB2)';
$lang['Rank_image_explain'] = '͸Ժٻ ѺдѺ';

$lang['Must_select_rank'] = 'سͧ͡дѺ';
$lang['No_assigned_rank'] = '˹дѺ';

$lang['Rank_updated'] = 'ѺاдѺº';
$lang['Rank_added'] = 'дѺº';
$lang['Rank_removed'] = 'źдѺº';
$lang['No_update_ranks'] = 'źдѺº ҼѧдѺ鹹ѧѺûѺا. سеͧЪͺѭմµͧ';

$lang['Click_return_rankadmin'] = 'ԡ %s%s ͡Ѻ˹ \'дѺ\'';


//
// Disallow Username Admin
//
$lang['Disallow_control'] = 'äǺ username ͹حҵ';
$lang['Disallow_explain'] = 'سöǺ͹حҵҹ. ͹حҵ Ҩѡ wildcard  *. سö͹حҵͼ ӡŧ¹͹ سеͧź ͹зӡ͹حҵ';

$lang['Delete_disallow'] = 'ź';
$lang['Delete_disallow_title'] = 'ź username ͹حҵ';
$lang['Delete_disallow_explain'] = 'سöź username ͹حҵ ͡ username ҡ¡ Ǥԡ ź';

$lang['Add_disallow'] = '';
$lang['Add_disallow_title'] = ' username ͹حҵ';
$lang['Add_disallow_explain'] = 'سöкͧ * ᷹ѡ';

$lang['No_disallowed'] = 'ª username ͹حҵ';

$lang['Disallowed_deleted'] = 'ź username ͹حҵ';
$lang['Disallow_successful'] = ' username ͹حҵ';
$lang['Disallowed_already'] = 'ö username . Ҩ username ¡, 㹡Һ,  username ';

$lang['Click_return_disallowadmin'] = 'ԡ %s%s ͡Ѻ˹ \'\'';


//
// Styles Admin
//
$lang['Styles_admin'] = 'õ駤ٻẺ';
$lang['Styles_explain'] = 'سö, ź ШѴٻẺ (template  theme) Ѻ';
$lang['Styles_addnew_explain'] = '¡ùٻẺس. ҧٻẺҨѧѺõԴŧҹ phpBB. ԡ \'Դ\' ҹҢͧٻẺ';

$lang['Select_template'] = '͡ template';

$lang['Style'] = 'ٻẺ';
$lang['Template'] = 'Template';
$lang['Install'] = 'Դ';
$lang['Download'] = 'Download';

$lang['Edit_theme'] = ' theme';
$lang['Edit_theme_explain'] = 'ҹҧسö䢡õ駤ҵҧ ͧٻẺ١͡';

$lang['Create_theme'] = 'ҧ theme ';
$lang['Create_theme_explain'] = 'ҹҧسöҧٻẺҡٻẺ١͡. кؤ (觤سŢҹ 6) سͧͧ # .. CCCCCC 鹶١ͧ,  #CCCCCC ١ͧ';

$lang['Export_themes'] = '͡ themes';
$lang['Export_explain'] = 'سö͡ٻẺ ͧٻẺ١͡. ͡ٻẺҡ¡ôҹҧ кҧõ駤ٻẺ Ѻѹ֡ directory ͧٻẺ. öѹ֡µͧ سӡ download ͧ. 觶Ҥسͧѹ֡س سͧ˹Է¹ webserver Ѻ directory ͧٻẺس͡. ٢ phpBB 2 users guide.';

$lang['Theme_installed'] = 'Դ theme ͡';
$lang['Style_removed'] = 'źٻẺ͡͡ҡҹ. Ҩźҧó سеͧźٻẺ ͡ҡ template directory .';
$lang['Theme_info_saved'] = 'ѹ֡´ͧ theme . سáѺ¹ҡ͹حҵͧ theme_info.cfg ( template directory س͡)  read-only';
$lang['Theme_updated'] = 'Ѻا theme ١͡. س͡õ駤 theme ';
$lang['Theme_created'] = 'ҧ theme . س͡õ駤 theme ͤʹ ';

$lang['Confirm_delete_style'] = 'سͧźٻẺ?';

$lang['Download_theme_cfg'] = '͡öҧ´ͧ theme. ԡҹҧ download  browser. ͤس download  سö directory Ѻ template. سö觵ͧ';
$lang['No_themes'] = ' theme  template س͡. ôԡ ҧ ᶺҹ';
$lang['No_template_dir'] = 'öԴ template directory. Ҩж١ҹ webserver Ҩԧ';
$lang['Cannot_remove_style'] = 'سöźٻẺ͡ ѹ١ٻẺҵðҹ. س¹ٻẺҵðҹͧ.';
$lang['Style_exists'] = 'ժͧ͢ٻẺ سҡѺ¹.';

$lang['Click_return_styleadmin'] = 'ԡ %s%s ͡Ѻ˹ \'õ駤ٻẺ\'';

$lang['Theme_settings'] = '駤 theme';
$lang['Theme_element'] = 'ǹСͺͧ theme';
$lang['Simple_name'] = ';鹰ҹ';
$lang['Value'] = '';
$lang['Save_Settings'] = 'ѹ֡';

$lang['Stylesheet'] = 'CSS Stylesheet';
$lang['Background_image'] = 'ٻѧ';
$lang['Background_color'] = 'վѧ';
$lang['Theme_name'] = ' theme';
$lang['Link_color'] = 'ԧ';
$lang['Text_color'] = 'յѡ';
$lang['VLink_color'] = 'ԧ';
$lang['ALink_color'] = 'ԧѧҹ';
$lang['HLink_color'] = 'ԧ좳ҧѺ';
$lang['Tr_color1'] = 'յҧ 1';
$lang['Tr_color2'] = 'յҧ 2';
$lang['Tr_color3'] = 'յҧ 3';
$lang['Tr_class1'] = 'Class ǵҧ 1';
$lang['Tr_class2'] = 'Class ǵҧ 2';
$lang['Tr_class3'] = 'Class ǵҧ 3';
$lang['Th_color1'] = 'բͧǵҧ 1';
$lang['Th_color2'] = 'բͧǵҧ 2';
$lang['Th_color3'] = 'բͧǵҧ 3';
$lang['Th_class1'] = 'Class ǵҧ 1';
$lang['Th_class2'] = 'Class ǵҧ 2';
$lang['Th_class3'] = 'Class ǵҧ 3';
$lang['Td_color1'] = 'բͧҧ 1';
$lang['Td_color2'] = 'բͧҧ 2';
$lang['Td_color3'] = 'բͧҧ 3';
$lang['Td_class1'] = 'բͧҧ 1';
$lang['Td_class2'] = 'բͧҧ 2';
$lang['Td_class3'] = 'բͧҧ 3';
$lang['fontface1'] = 'Ẻѡ÷ 1';
$lang['fontface2'] = 'Ẻѡ÷ 2';
$lang['fontface3'] = 'Ẻѡ÷ 3';
$lang['fontsize1'] = 'Ҵѡ÷ 1';
$lang['fontsize2'] = 'Ҵѡ÷ 2';
$lang['fontsize3'] = 'Ҵѡ÷ 3';
$lang['fontcolor1'] = 'յѡ÷ 1';
$lang['fontcolor2'] = 'յѡ÷ 2';
$lang['fontcolor3'] = 'յѡ÷ 3';
$lang['span_class1'] = 'Span Class 1';
$lang['span_class2'] = 'Span Class 2';
$lang['span_class3'] = 'Span Class 3';
$lang['img_poll_size'] = 'ҴٻҾẺǨ [px]';
$lang['img_pm_size'] = 'ҴʶҹТͤǹ [px]';


//
// Install Process
//
$lang['Welcome_install'] = 'Թյ͹ѺõԴ phpBB 2';
$lang['Initial_config'] = 'õ駤Ҿ鹰ҹ';
$lang['DB_config'] = 'õ駤Ұҹ';
$lang['Admin_config'] = 'õ駤 Admin';
$lang['continue_upgrade'] = 'ͤس download õ駤ŧͧͧس ԡ \'ӡѻô\' ҹҧ ѧкǹѻô. س͢зӡõ駤 ҡкǹѻô.';
$lang['upgrade_submit'] = 'ӡѻô';

$lang['Installer_Error'] = 'ԴͼԴҴҧõԴ';
$lang['Previous_Install'] = 'ǨաõԴҡ͹';
$lang['Install_db_error'] = 'ԴͼԴҴ㹡þѺاҹ';

$lang['Re_install'] = 'õԴ駤駡͹ѧ. <br /><br />ҤسͧõԴ phpBB 2  سäԡ Yes ҹҧ. ôѧҡ÷蹹 з¢ŷ Шաͧ! ʼҹͧ administrator سж١ҧ աõ駤ŧա<br /><br />سҤԴͺͺ͹ԡ Yes!';

$lang['Inst_Step_0'] = 'ͺس phpBB 2. õԴó سҡ͡´ҹҧ. سҵǨͺ͹ҪͰҹŷس١ҧ͹. ҤسѧԴŧҹ ODBC  MS Access سèҧ DSN ¡͹';

$lang['Start_Install'] = 'Դ';
$lang['Finish_Install'] = 'õԴ';

$lang['Default_lang'] = 'ҵðҹͧ';
$lang['DB_Host'] = 'Database Server Hostname / DSN';
$lang['DB_Name'] = 'ͰҹŢͧس';
$lang['DB_Username'] = 'Database Username';
$lang['DB_Password'] = 'Database Password';
$lang['Database'] = 'ҹŢͧس';
$lang['Install_lang'] = '͡㹡õԴ';
$lang['dbms'] = 'Դҹ';
$lang['Table_Prefix'] = '鹵鹪͵ҧ㹰ҹŴ¤';
$lang['Admin_Username'] = 'Administrator Username';
$lang['Admin_Password'] = 'Administrator Password';
$lang['Admin_Password_confirm'] = 'Administrator Password [׹ѹ]';

$lang['Inst_Step_2'] = 'ҧѭ admin ͧس. йõԴ駾鹰ҹó. سж١ѧ˹Ѻõ駤ҷ. سҵǨͺ´ͧ \'õ駤ҷ\' ǹͧ. ͺس phpBB 2.';

$lang['Unwriteable_config'] = 'õ駤Ңͧس ١˹Էö. ͤسԡҹҧ õ駤Ҩж١س download. س upload Ѻ directory ǡѹѺ phpBB 2. кºѭբͧ administrator ͡ ҡ价 Admin Control Panel (ԧҹҧͧ˹ к) ͵Ǩͺõ駤ҷ. ͺس phpBB 2.';
$lang['Download_config'] = 'Download õ駤';

$lang['ftp_choose'] = '͡Ըա Download';
$lang['ftp_option'] = '<br />աõԴк FTP ŧ PHP 蹹 سҨк FTP ѵѵ';
$lang['ftp_instructs'] = 'س͡к FTP ѵѵ. سҡ͡Ŵҹҧ. ˹ FTP èеçѺ˹ FTP ӡõԴ phpBB2 ͹ҧس FTP ';
$lang['ftp_info'] = 'سҡ͡ FTP ͧس';
$lang['Attempt_ftp'] = '駤ҡ FTP ';
$lang['Send_file'] = 'ѹ ǩѹ FTP  upload ׹µͧ';
$lang['ftp_path'] = '˹ FTP ͧ phpBB 2';
$lang['ftp_username'] = 'FTP Username';
$lang['ftp_password'] = 'FTP Password';
$lang['Transfer_config'] = '';
$lang['NoFTP_config'] = 'þõ駤ҷҧ FTP . س download õ駤 ҷҧ FTP µǤسͧ';

$lang['Install'] = 'Դ';
$lang['Upgrade'] = 'ѻô';


$lang['Install_Method'] = 'س͡ԸաõԴ';

$lang['Install_No_Ext'] = 'õ駤 php  server ͧس ʹѺʹعҹŷس͡';

$lang['Install_No_PCRE'] = 'phpBB2 ͧ Perl-Compatible Regular Expressions Module Ѻ php. 觻ҡҡõ駤 php ͧسʹѺʹع!';

//
// That's all Folks!
// -------------------------------------------------

?>